==> estateplat-common-1.2.4-20190715.080055-196-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtJftjsx.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    商品房交付条件与交付手续(第四章)
 */
@Table(name = "fcjy_xjspf_mmht_jftjsx")
public class FcjyXjspfMmhtJftjsx implements Serializable {
    @Id
    private String jfid;//主键
    private String htid;//合同ID
    private String jftjfhx3;//交付条件符合项3
    private String jftj3;//交付条件三
    private String jftj4;//交付条件四
    private String gsqt;//供水其他
    private String gdqt;//供电其他
    private String gnqt;//供暖其他
    private String rqqt;//燃气其他
    private String jcssyqjfclfs;//基础设施逾期交付处理方式
    private Double dwxzfwyjje;//第五项支付违约金金额(元)
    private Double dlxzfwyjje;//第六项支付违约金金额(元)
    private Double dqxzfwyjje;//第七项支付违约金金额(元)
    private Integer xcbzjfts;//下次保证交付天数
    private String jcssyqjfqtfs;//基础设施逾期交付其他方式
    private String ldlqx;//绿地率期限
    private String ldldd;//绿地率达到
    private String fszdlqx;//非市政道路期限
    private String fszdldd;//非市政道路达到
    private String ghcwqx;//规划车位期限
    private String ghcwdd;//规划车位达到
    private String wyfwyfqx;//物业服务用房期限
    private String wyfwyfdd;//物业服务用房达到
    private String ylwsjgqx;//医疗卫生机构期限
    private String ylwsjgdd;//医疗卫生机构达到
    private String yeyqx;//幼儿园期限
    private String yeydd;//幼儿园达到
    private String xxqx;//学校期限
    private String xxdd;//学校达到
    private String ptssqt1;//配套设施其他1
    private String ptssqt2;//配套设施其他2
    private String ldlwddclfs;//绿地率未达到处理方式
    private String fszdlwddclfs;//非市政道路未达到处理方式
    private String ghcwwddclfs;//规划车位未达到处理方式
    private String wyfwwddclfs;//物业服务未达到处理方式
    private String qtsswddclfs;//其他设施未达到处理方式
    private String jfsj;//交付时间
    private Integer jftzts;//交付通知天数
    private String jfqt;//交付其他
    private Integer xxrnxf;//查验次日起XX日内修复
    private String xfnr1;//修复内容其他1
    private String xfnr2;//修复内容其他2
    private String cywjfcl1;//查验未交付处理1
    private String cywjfcl2;//查验未交付处理2
    private String jfyqclfs;//交付逾期处理方式
    private Integer jfyqxxrn;//交付逾期XX日内
    private Double jfyqxrnwfzxwyj;//交付逾期X日内万分之X违约金
    private Integer jfyqcxxr;//交付逾期超XX日
    private String yqcjflx;//逾期超给付利息(日)
    private Double yqcwyj;//逾期超违约金(百分之)
    private Double fjkwfzxwyj;//房价款万分之X违约金
    private String jfyqqtfs;//交付逾期其他方式
    private String jftjfhx4;//交付条件符合项4

    public String getJfid() {
        return jfid;
    }

    public void setJfid(String jfid) {
        this.jfid = jfid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJftjfhx3() {
        return jftjfhx3;
    }

    public void setJftjfhx3(String jftjfhx3) {
        this.jftjfhx3 = jftjfhx3;
    }

    public String getJftj3() {
        return jftj3;
    }

    public void setJftj3(String jftj3) {
        this.jftj3 = jftj3;
    }

    public String getJftj4() {
        return jftj4;
    }

    public void setJftj4(String jftj4) {
        this.jftj4 = jftj4;
    }

    public String getGsqt() {
        return gsqt;
    }

    public void setGsqt(String gsqt) {
        this.gsqt = gsqt;
    }

    public String getGdqt() {
        return gdqt;
    }

    public void setGdqt(String gdqt) {
        this.gdqt = gdqt;
    }

    public String getGnqt() {
        return gnqt;
    }

    public void setGnqt(String gnqt) {
        this.gnqt = gnqt;
    }

    public String getRqqt() {
        return rqqt;
    }

    public void setRqqt(String rqqt) {
        this.rqqt = rqqt;
    }

    public String getJcssyqjfclfs() {
        return jcssyqjfclfs;
    }

    public void setJcssyqjfclfs(String jcssyqjfclfs) {
        this.jcssyqjfclfs = jcssyqjfclfs;
    }

    public Double getDwxzfwyjje() {
        return dwxzfwyjje;
    }

    public void setDwxzfwyjje(Double dwxzfwyjje) {
        this.dwxzfwyjje = dwxzfwyjje;
    }

    public Double getDlxzfwyjje() {
        return dlxzfwyjje;
    }

    public void setDlxzfwyjje(Double dlxzfwyjje) {
        this.dlxzfwyjje = dlxzfwyjje;
    }

    public Double getDqxzfwyjje() {
        return dqxzfwyjje;
    }

    public void setDqxzfwyjje(Double dqxzfwyjje) {
        this.dqxzfwyjje = dqxzfwyjje;
    }

    public Integer getXcbzjfts() {
        return xcbzjfts;
    }

    public void setXcbzjfts(Integer xcbzjfts) {
        this.xcbzjfts = xcbzjfts;
    }

    public String getJcssyqjfqtfs() {
        return jcssyqjfqtfs;
    }

    public void setJcssyqjfqtfs(String jcssyqjfqtfs) {
        this.jcssyqjfqtfs = jcssyqjfqtfs;
    }

    public String getLdlqx() {
        return ldlqx;
    }

    public void setLdlqx(String ldlqx) {
        this.ldlqx = ldlqx;
    }

    public String getLdldd() {
        return ldldd;
    }

    public void setLdldd(String ldldd) {
        this.ldldd = ldldd;
    }

    public String getFszdlqx() {
        return fszdlqx;
    }

    public void setFszdlqx(String fszdlqx) {
        this.fszdlqx = fszdlqx;
    }

    public String getFszdldd() {
        return fszdldd;
    }

    public void setFszdldd(String fszdldd) {
        this.fszdldd = fszdldd;
    }

    public String getGhcwqx() {
        return ghcwqx;
    }

    public void setGhcwqx(String ghcwqx) {
        this.ghcwqx = ghcwqx;
    }

    public String getGhcwdd() {
        return ghcwdd;
    }

    public void setGhcwdd(String ghcwdd) {
        this.ghcwdd = ghcwdd;
    }

    public String getWyfwyfqx() {
        return wyfwyfqx;
    }

    public void setWyfwyfqx(String wyfwyfqx) {
        this.wyfwyfqx = wyfwyfqx;
    }

    public String getWyfwyfdd() {
        return wyfwyfdd;
    }

    public void setWyfwyfdd(String wyfwyfdd) {
        this.wyfwyfdd = wyfwyfdd;
    }

    public String getYlwsjgqx() {
        return ylwsjgqx;
    }

    public void setYlwsjgqx(String ylwsjgqx) {
        this.ylwsjgqx = ylwsjgqx;
    }

    public String getYlwsjgdd() {
        return ylwsjgdd;
    }

    public void setYlwsjgdd(String ylwsjgdd) {
        this.ylwsjgdd = ylwsjgdd;
    }

    public String getYeyqx() {
        return yeyqx;
    }

    public void setYeyqx(String yeyqx) {
        this.yeyqx = yeyqx;
    }

    public String getYeydd() {
        return yeydd;
    }

    public void setYeydd(String yeydd) {
        this.yeydd = yeydd;
    }

    public String getXxqx() {
        return xxqx;
    }

    public void setXxqx(String xxqx) {
        this.xxqx = xxqx;
    }

    public String getXxdd() {
        return xxdd;
    }

    public void setXxdd(String xxdd) {
        this.xxdd = xxdd;
    }

    public String getPtssqt1() {
        return ptssqt1;
    }

    public void setPtssqt1(String ptssqt1) {
        this.ptssqt1 = ptssqt1;
    }

    public String getPtssqt2() {
        return ptssqt2;
    }

    public void setPtssqt2(String ptssqt2) {
        this.ptssqt2 = ptssqt2;
    }

    public String getLdlwddclfs() {
        return ldlwddclfs;
    }

    public void setLdlwddclfs(String ldlwddclfs) {
        this.ldlwddclfs = ldlwddclfs;
    }

    public String getFszdlwddclfs() {
        return fszdlwddclfs;
    }

    public void setFszdlwddclfs(String fszdlwddclfs) {
        this.fszdlwddclfs = fszdlwddclfs;
    }

    public String getGhcwwddclfs() {
        return ghcwwddclfs;
    }

    public void setGhcwwddclfs(String ghcwwddclfs) {
        this.ghcwwddclfs = ghcwwddclfs;
    }

    public String getWyfwwddclfs() {
        return wyfwwddclfs;
    }

    public void setWyfwwddclfs(String wyfwwddclfs) {
        this.wyfwwddclfs = wyfwwddclfs;
    }

    public String getQtsswddclfs() {
        return qtsswddclfs;
    }

    public void setQtsswddclfs(String qtsswddclfs) {
        this.qtsswddclfs = qtsswddclfs;
    }

    public String getJfsj() {
        return jfsj;
    }

    public void setJfsj(String jfsj) {
        this.jfsj = jfsj;
    }

    public Integer getJftzts() {
        return jftzts;
    }

    public void setJftzts(Integer jftzts) {
        this.jftzts = jftzts;
    }

    public String getJfqt() {
        return jfqt;
    }

    public void setJfqt(String jfqt) {
        this.jfqt = jfqt;
    }

    public Integer getXxrnxf() {
        return xxrnxf;
    }

    public void setXxrnxf(Integer xxrnxf) {
        this.xxrnxf = xxrnxf;
    }

    public String getXfnr1() {
        return xfnr1;
    }

    public void setXfnr1(String xfnr1) {
        this.xfnr1 = xfnr1;
    }

    public String getXfnr2() {
        return xfnr2;
    }

    public void setXfnr2(String xfnr2) {
        this.xfnr2 = xfnr2;
    }

    public String getCywjfcl1() {
        return cywjfcl1;
    }

    public void setCywjfcl1(String cywjfcl1) {
        this.cywjfcl1 = cywjfcl1;
    }

    public String getCywjfcl2() {
        return cywjfcl2;
    }

    public void setCywjfcl2(String cywjfcl2) {
        this.cywjfcl2 = cywjfcl2;
    }

    public String getJfyqclfs() {
        return jfyqclfs;
    }

    public void setJfyqclfs(String jfyqclfs) {
        this.jfyqclfs = jfyqclfs;
    }

    public Integer getJfyqxxrn() {
        return jfyqxxrn;
    }

    public void setJfyqxxrn(Integer jfyqxxrn) {
        this.jfyqxxrn = jfyqxxrn;
    }

    public Double getJfyqxrnwfzxwyj() {
        return jfyqxrnwfzxwyj;
    }

    public void setJfyqxrnwfzxwyj(Double jfyqxrnwfzxwyj) {
        this.jfyqxrnwfzxwyj = jfyqxrnwfzxwyj;
    }

    public Integer getJfyqcxxr() {
        return jfyqcxxr;
    }

    public void setJfyqcxxr(Integer jfyqcxxr) {
        this.jfyqcxxr = jfyqcxxr;
    }

    public String getYqcjflx() {
        return yqcjflx;
    }

    public void setYqcjflx(String yqcjflx) {
        this.yqcjflx = yqcjflx;
    }

    public Double getYqcwyj() {
        return yqcwyj;
    }

    public void setYqcwyj(Double yqcwyj) {
        this.yqcwyj = yqcwyj;
    }

    public Double getFjkwfzxwyj() {
        return fjkwfzxwyj;
    }

    public void setFjkwfzxwyj(Double fjkwfzxwyj) {
        this.fjkwfzxwyj = fjkwfzxwyj;
    }

    public String getJfyqqtfs() {
        return jfyqqtfs;
    }

    public void setJfyqqtfs(String jfyqqtfs) {
        this.jfyqqtfs = jfyqqtfs;
    }

    public String getJftjfhx4() {
        return jftjfhx4;
    }

    public void setJftjfhx4(String jftjfhx4) {
        this.jftjfhx4 = jftjfhx4;
    }
}

==> estateplat-common-1.2.4-20210628.113644-802-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfMmhtJftjsx.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
 * @version 1.0, 2017/12/6
 * @description    商品房交付条件与交付手续(第四章)
 */
@Table(name = "fcjy_xjspf_mmht_jftjsx")
public class FcjyXjspfMmhtJftjsx implements Serializable {
    @Id
    private String jfid;//主键
    private String htid;//合同ID
    private String jftjfhx3;//交付条件符合项3
    private String jftj3;//交付条件三
    private String jftj4;//交付条件四
    private String gsqt;//供水其他
    private String gdqt;//供电其他
    private String gnqt;//供暖其他
    private String rqqt;//燃气其他
    private String jcssyqjfclfs;//基础设施逾期交付处理方式
    private Double dwxzfwyjje;//第五项支付违约金金额(元)
    private Double dlxzfwyjje;//第六项支付违约金金额(元)
    private Double dqxzfwyjje;//第七项支付违约金金额(元)
    private Integer xcbzjfts;//下次保证交付天数
    private String jcssyqjfqtfs;//基础设施逾期交付其他方式
    private String ldlqx;//绿地率期限
    private String ldldd;//绿地率达到
    private String fszdlqx;//非市政道路期限
    private String fszdldd;//非市政道路达到
    private String ghcwqx;//规划车位期限
    private String ghcwdd;//规划车位达到
    private String wyfwyfqx;//物业服务用房期限
    private String wyfwyfdd;//物业服务用房达到
    private String ylwsjgqx;//医疗卫生机构期限
    private String ylwsjgdd;//医疗卫生机构达到
    private String yeyqx;//幼儿园期限
    private String yeydd;//幼儿园达到
    private String xxqx;//学校期限
    private String xxdd;//学校达到
    private String ptssqt1;//配套设施其他1
    private String ptssqt2;//配套设施其他2
    private String ldlwddclfs;//绿地率未达到处理方式
    private String fszdlwddclfs;//非市政道路未达到处理方式
    private String ghcwwddclfs;//规划车位未达到处理方式
    private String wyfwwddclfs;//物业服务未达到处理方式
    private String qtsswddclfs;//其他设施未达到处理方式
    private String jfsj;//交付时间
    private Integer jftzts;//交付通知天数
    private String jfqt;//交付其他
    private Integer xxrnxf;//查验次日起XX日内修复
    private String xfnr1;//修复内容其他1
    private String xfnr2;//修复内容其他2
    private String cywjfcl1;//查验未交付处理1
    private String cywjfcl2;//查验未交付处理2
    private String jfyqclfs;//交付逾期处理方式
    private Integer jfyqxxrn;//交付逾期XX日内
    private Double jfyqxrnwfzxwyj;//交付逾期X日内万分之X违约金
    private Integer jfyqcxxr;//交付逾期超XX日
    private String yqcjflx;//逾期超给付利息(日)
    private Double yqcwyj;//逾期超违约金(百分之)
    private Double fjkwfzxwyj;//房价款万分之X违约金
    private String jfyqqtfs;//交付逾期其他方式
    private String jftjfhx4;//交付条件符合项4
    private String gntj;//供暖条件

    public String getJfid() {
        return jfid;
    }

    public void setJfid(String jfid) {
        this.jfid = jfid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJftjfhx3() {
        return jftjfhx3;
    }

    public void setJftjfhx3(String jftjfhx3) {
        this.jftjfhx3 = jftjfhx3;
    }

    public String getJftj3() {
        return jftj3;
    }

    public void setJftj3(String jftj3) {
        this.jftj3 = jftj3;
    }

    public String getJftj4() {
        return jftj4;
    }

    public void setJftj4(String jftj4) {
        this.jftj4 = jftj4;
    }

    public String getGsqt() {
        return gsqt;
    }

    public void setGsqt(String gsqt) {
        this.gsqt = gsqt;
    }

    public String getGdqt() {
        return gdqt;
    }

    public void setGdqt(String gdqt) {
        this.gdqt = gdqt;
    }

    public String getGnqt() {
        return gnqt;
    }

    public void setGnqt(String gnqt) {
        this.gnqt = gnqt;
    }

    public String getRqqt() {
        return rqqt;
    }

    public void setRqqt(String rqqt) {
        this.rqqt = rqqt;
    }

    public String getJcssyqjfclfs() {
        return jcssyqjfclfs;
    }

    public void setJcssyqjfclfs(String jcssyqjfclfs) {
        this.jcssyqjfclfs = jcssyqjfclfs;
    }

    public Double getDwxzfwyjje() {
        return dwxzfwyjje;
    }

    public void setDwxzfwyjje(Double dwxzfwyjje) {
        this.dwxzfwyjje = dwxzfwyjje;
    }

    public Double getDlxzfwyjje() {
        return dlxzfwyjje;
    }

    public void setDlxzfwyjje(Double dlxzfwyjje) {
        this.dlxzfwyjje = dlxzfwyjje;
    }

    public Double getDqxzfwyjje() {
        return dqxzfwyjje;
    }

    public void setDqxzfwyjje(Double dqxzfwyjje) {
        this.dqxzfwyjje = dqxzfwyjje;
    }

    public Integer getXcbzjfts() {
        return xcbzjfts;
    }

    public void setXcbzjfts(Integer xcbzjfts) {
        this.xcbzjfts = xcbzjfts;
    }

    public String getJcssyqjfqtfs() {
        return jcssyqjfqtfs;
    }

    public void setJcssyqjfqtfs(String jcssyqjfqtfs) {
        this.jcssyqjfqtfs = jcssyqjfqtfs;
    }

    public String getLdlqx() {
        return ldlqx;
    }

    public void setLdlqx(String ldlqx) {
        this.ldlqx = ldlqx;
    }

    public String getLdldd() {
        return ldldd;
    }

    public void setLdldd(String ldldd) {
        this.ldldd = ldldd;
    }

    public String getFszdlqx() {
        return fszdlqx;
    }

    public void setFszdlqx(String fszdlqx) {
        this.fszdlqx = fszdlqx;
    }

    public String getFszdldd() {
        return fszdldd;
    }

    public void setFszdldd(String fszdldd) {
        this.fszdldd = fszdldd;
    }

    public String getGhcwqx() {
        return ghcwqx;
    }

    public void setGhcwqx(String ghcwqx) {
        this.ghcwqx = ghcwqx;
    }

    public String getGhcwdd() {
        return ghcwdd;
    }

    public void setGhcwdd(String ghcwdd) {
        this.ghcwdd = ghcwdd;
    }

    public String getWyfwyfqx() {
        return wyfwyfqx;
    }

    public void setWyfwyfqx(String wyfwyfqx) {
        this.wyfwyfqx = wyfwyfqx;
    }

    public String getWyfwyfdd() {
        return wyfwyfdd;
    }

    public void setWyfwyfdd(String wyfwyfdd) {
        this.wyfwyfdd = wyfwyfdd;
    }

    public String getYlwsjgqx() {
        return ylwsjgqx;
    }

    public void setYlwsjgqx(String ylwsjgqx) {
        this.ylwsjgqx = ylwsjgqx;
    }

    public String getYlwsjgdd() {
        return ylwsjgdd;
    }

    public void setYlwsjgdd(String ylwsjgdd) {
        this.ylwsjgdd = ylwsjgdd;
    }

    public String getYeyqx() {
        return yeyqx;
    }

    public void setYeyqx(String yeyqx) {
        this.yeyqx = yeyqx;
    }

    public String getYeydd() {
        return yeydd;
    }

    public void setYeydd(String yeydd) {
        this.yeydd = yeydd;
    }

    public String getXxqx() {
        return xxqx;
    }

    public void setXxqx(String xxqx) {
        this.xxqx = xxqx;
    }

    public String getXxdd() {
        return xxdd;
    }

    public void setXxdd(String xxdd) {
        this.xxdd = xxdd;
    }

    public String getPtssqt1() {
        return ptssqt1;
    }

    public void setPtssqt1(String ptssqt1) {
        this.ptssqt1 = ptssqt1;
    }

    public String getPtssqt2() {
        return ptssqt2;
    }

    public void setPtssqt2(String ptssqt2) {
        this.ptssqt2 = ptssqt2;
    }

    public String getLdlwddclfs() {
        return ldlwddclfs;
    }

    public void setLdlwddclfs(String ldlwddclfs) {
        this.ldlwddclfs = ldlwddclfs;
    }

    public String getFszdlwddclfs() {
        return fszdlwddclfs;
    }

    public void setFszdlwddclfs(String fszdlwddclfs) {
        this.fszdlwddclfs = fszdlwddclfs;
    }

    public String getGhcwwddclfs() {
        return ghcwwddclfs;
    }

    public void setGhcwwddclfs(String ghcwwddclfs) {
        this.ghcwwddclfs = ghcwwddclfs;
    }

    public String getWyfwwddclfs() {
        return wyfwwddclfs;
    }

    public void setWyfwwddclfs(String wyfwwddclfs) {
        this.wyfwwddclfs = wyfwwddclfs;
    }

    public String getQtsswddclfs() {
        return qtsswddclfs;
    }

    public void setQtsswddclfs(String qtsswddclfs) {
        this.qtsswddclfs = qtsswddclfs;
    }

    public String getJfsj() {
        return jfsj;
    }

    public void setJfsj(String jfsj) {
        this.jfsj = jfsj;
    }

    public Integer getJftzts() {
        return jftzts;
    }

    public void setJftzts(Integer jftzts) {
        this.jftzts = jftzts;
    }

    public String getJfqt() {
        return jfqt;
    }

    public void setJfqt(String jfqt) {
        this.jfqt = jfqt;
    }

    public Integer getXxrnxf() {
        return xxrnxf;
    }

    public void setXxrnxf(Integer xxrnxf) {
        this.xxrnxf = xxrnxf;
    }

    public String getXfnr1() {
        return xfnr1;
    }

    public void setXfnr1(String xfnr1) {
        this.xfnr1 = xfnr1;
    }

    public String getXfnr2() {
        return xfnr2;
    }

    public void setXfnr2(String xfnr2) {
        this.xfnr2 = xfnr2;
    }

    public String getCywjfcl1() {
        return cywjfcl1;
    }

    public void setCywjfcl1(String cywjfcl1) {
        this.cywjfcl1 = cywjfcl1;
    }

    public String getCywjfcl2() {
        return cywjfcl2;
    }

    public void setCywjfcl2(String cywjfcl2) {
        this.cywjfcl2 = cywjfcl2;
    }

    public String getJfyqclfs() {
        return jfyqclfs;
    }

    public void setJfyqclfs(String jfyqclfs) {
        this.jfyqclfs = jfyqclfs;
    }

    public Integer getJfyqxxrn() {
        return jfyqxxrn;
    }

    public void setJfyqxxrn(Integer jfyqxxrn) {
        this.jfyqxxrn = jfyqxxrn;
    }

    public Double getJfyqxrnwfzxwyj() {
        return jfyqxrnwfzxwyj;
    }

    public void setJfyqxrnwfzxwyj(Double jfyqxrnwfzxwyj) {
        this.jfyqxrnwfzxwyj = jfyqxrnwfzxwyj;
    }

    public Integer getJfyqcxxr() {
        return jfyqcxxr;
    }

    public void setJfyqcxxr(Integer jfyqcxxr) {
        this.jfyqcxxr = jfyqcxxr;
    }

    public String getYqcjflx() {
        return yqcjflx;
    }

    public void setYqcjflx(String yqcjflx) {
        this.yqcjflx = yqcjflx;
    }

    public Double getYqcwyj() {
        return yqcwyj;
    }

    public void setYqcwyj(Double yqcwyj) {
        this.yqcwyj = yqcwyj;
    }

    public Double getFjkwfzxwyj() {
        return fjkwfzxwyj;
    }

    public void setFjkwfzxwyj(Double fjkwfzxwyj) {
        this.fjkwfzxwyj = fjkwfzxwyj;
    }

    public String getJfyqqtfs() {
        return jfyqqtfs;
    }

    public void setJfyqqtfs(String jfyqqtfs) {
        this.jfyqqtfs = jfyqqtfs;
    }

    public String getJftjfhx4() {
        return jftjfhx4;
    }

    public void setJftjfhx4(String jftjfhx4) {
        this.jftjfhx4 = jftjfhx4;
    }

    public String getGntj() {
        return gntj;
    }

    public void setGntj(String gntj) {
        this.gntj = gntj;
    }
}
